# Code generated by highflame-policy-codegen. DO NOT EDIT.
# Source: schemas/overwatch/context.json

"""Context attribute keys for Overwatch Overwatch (Guardian) IDE security & policy enforcement."""

class OverwatchContextKey:
    """Context keys for Overwatch policy evaluation."""

    CONTAINS_SECRETS: str = "contains_secrets"
    CONTENT: str = "content"
    CWD: str = "cwd"
    EVENT: str = "event"
    HIGHEST_SEVERITY: str = "highest_severity"
    MAX_THREAT_SEVERITY: str = "max_threat_severity"
    MCP_SERVER: str = "mcp_server"
    MCP_TOOL: str = "mcp_tool"
    PATH: str = "path"
    PROMPT_TEXT: str = "prompt_text"
    RESPONSE_CONTENT: str = "response_content"
    SOURCE: str = "source"
    THREAT_CATEGORIES: str = "threat_categories"
    THREAT_COUNT: str = "threat_count"
    THREAT_TYPES: str = "threat_types"
    TOOL_NAME: str = "tool_name"
    USER_EMAIL: str = "user_email"
    WORKSPACE_ROOT: str = "workspace_root"
    YARA_THREATS: str = "yara_threats"
